@@ -6,8 +6,8 @@
 """
 *SVG Schematic* is a Python library can be used to create schematics using SVG.
 """
-__version__ = '0.7.0'
-__released__ = '2020-03-02'
+__version__ = '1.0.0'
+__released__ = '2020-04-16'
 
 
 # License {{{1
@@ -235,7 +235,8 @@ class Wire(Schematic): # {{{1
 
         # add the beginning and end points as attributes.
         self.b = points[0]
-        self.e = points[1]
+        self.e = points[-1]
+        self.m = midpoint(self.b, self.e)
 
         # preprocess points to add corners when manhattan geometry is requested
         if kind != 'plain':
